@@ -1,4 +1,5 @@
 from .resources.community import CommunityResource
+from .resources.group import GroupResource
 from .resources.subgroup import SubgroupResource
 from .version import __version__
 from .requestor import Requestor
@@ -11,6 +12,7 @@ class ApiClient(object):
         self._timeout = timeout
         self._requestor = Requestor(api_url=self._api_url, api_key=self._api_key, timeout=self._timeout)
         self._community = CommunityResource(api_url=self._api_url, requestor=self._requestor)
+        self._group = GroupResource(api_url=self._api_url, requestor=self._requestor)
         self._subgroup = SubgroupResource(api_url=self._api_url, requestor=self._requestor)
 
     @property
@@ -33,6 +35,10 @@ class ApiClient(object):
     def community(self) -> CommunityResource:
         return self._community
 
+    @property
+    def group(self) -> GroupResource:
+        return self._group
+
     @property
     def subgroup(self) -> SubgroupResource:
         return self._subgroup
